@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.61_01'; # TRIAL VERSION
+our $VERSION = '1.90_01'; # TRIAL VERSION
 
 # Platypus-Man,
 # Platypus-Man,
@@ -57,8 +57,12 @@ sub new
   {
     Carp::croak("Please do not use the experimental version of api = 1, instead require FFI::Platypus 1.00 or better");
   }
+  elsif($experimental == 2)
+  {
+    Carp::croak("Please do not use the experimental version of api = 2, instead require FFI::Platypus 2.00 or better");
+  }
 
-  if(defined $api && $api > 1 && $experimental != $api)
+  if(defined $api && $api > 2 && $experimental != $api)
   {
     Carp::cluck("Enabling development API version $api prior to FFI::Platypus $api.00");
   }
@@ -593,7 +597,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.61_01
+version 1.90_01
 
 =head1 SYNOPSIS
 
@@ -2362,18 +2366,21 @@ the development package for C<libffi> as prereqs for this module.
 
 Type definitions for Platypus.
 
-=item L<FFI::Platypus::Record>
-
-Define structured data records (C "structs") for use with
-Platypus.
-
 =item L<FFI::C>
 
-Another interface for defining structured data records for use
-with Platypus.  Its advantage over L<FFI::Platypus::Record> is
-that it supports C<union>s and nested data structures.  Its
-disadvantage is that it doesn't support passing C<struct>s
-by-value.
+Interface for defining structured data records for use with
+Platypus.  It supports C C<struct>, C<union>, nested structures
+and arrays of all of those.  It only supports passing these
+types by reference or pointer, so if you need to pass structured
+data by value see L<FFI::Platypus::Record> below.
+
+=item L<FFI::Platypus::Record>
+
+Interface for defining structured data records for use with
+Platypus.  Included in the Platypus core.  Supports pass by
+value which is uncommon in C, but frequently used in languages
+like Rust and Go.  Consider using L<FFI::C> instead if you
+don't need to pass by value.
 
 =item L<FFI::Platypus::API>
 
