@@ -11,21 +11,21 @@ use constant 1.32 ();
 our @EXPORT = qw( record_layout record_layout_1 );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '1.61_01'; # TRIAL VERSION
+our $VERSION = '1.90_01'; # TRIAL VERSION
 
 
 sub record_layout_1
 {
   if(@_ % 2 == 0)
   {
-    my $ffi = FFI::Platypus->new( api => 2, experimental => 2 );
+    my $ffi = FFI::Platypus->new( api => 2);
     unshift @_, $ffi;
     goto &record_layout;
   }
   elsif(defined $_[0] && ref($_[0]) eq 'ARRAY')
   {
     my @args = @{ shift @_ };
-    unshift @args, api => 2, experimental => 2;
+    unshift @args, api => 2;
     unshift @_, \@args;
     goto &record_layout;
   }
@@ -204,7 +204,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 1.61_01
+version 1.90_01
 
 =head1 SYNOPSIS
 
@@ -270,6 +270,10 @@ Before you get to deep into using this class you should also consider
 the L<FFI::C>, which provides some overlapping functionality.  Briefly,
 it comes down to this:
 
+(The tl;dr is: use this class when you need to pass by value (since
+L<FFI::C> does not support pass by value) and use L<FFI::C> in all
+other circumstances).
+
 =over 4
 
 =item L<FFI::Platypus::Record>
