@@ -7,14 +7,14 @@ use FFI::Platypus;
 use Scalar::Util qw( readonly );
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '1.61_01'; # TRIAL VERSION
+our $VERSION = '1.90_01'; # TRIAL VERSION
 
 
 use constant _incantation =>
   $^O eq 'MSWin32' && do { require Config; $Config::Config{archname} =~ /MSWin32-x64/ }
   ? 'Q'
   : 'L!';
-use constant _pointer_buffer => "P" . FFI::Platypus->new( api => 2, experimental => 2 )->sizeof('opaque');
+use constant _pointer_buffer => "P" . FFI::Platypus->new( api => 2 )->sizeof('opaque');
 
 my @stack;
 
@@ -76,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 1.61_01
+version 1.90_01
 
 =head1 SYNOPSIS
 
