@@ -10,7 +10,7 @@ use Encode qw( decode encode find_encoding );
 use Carp ();
 
 # ABSTRACT: Platypus custom type for Unicode "wide" strings
-our $VERSION = '1.61_01'; # TRIAL VERSION
+our $VERSION = '1.90_01'; # TRIAL VERSION
 
 
 my @stack;  # To keep buffer alive.
@@ -23,7 +23,7 @@ sub _compute_wide_string_encoding
       unless FFI::Platypus::Memory->can("_$need");
   }
 
-  my $ffi = FFI::Platypus->new( api => 2, experimental => 2, lib => [undef] );
+  my $ffi = FFI::Platypus->new( api => 2, lib => [undef] );
 
   my $size = eval { $ffi->sizeof('wchar_t') };
   die 'no wchar_t' if $@;
@@ -187,7 +187,7 @@ FFI::Platypus::Type::WideString - Platypus custom type for Unicode "wide" string
 
 =head1 VERSION
 
-version 1.61_01
+version 1.90_01
 
 =head1 SYNOPSIS
 
